@@ -1,5 +1,38 @@
 var NAVTREEINDEX27 =
 {
+"d2/d83/dhcp4__lexer_8cc.html#a4fd44867d448dcb6fc32ea004a15de54":[8,0,0,0,2,4,130],
+"d2/d83/dhcp4__lexer_8cc.html#a5206f64af3a299a0dc820c385cf0c489":[8,0,0,0,2,4,81],
+"d2/d83/dhcp4__lexer_8cc.html#a53579db42834b88199458993912c646d":[8,0,0,0,2,4,57],
+"d2/d83/dhcp4__lexer_8cc.html#a5611300548b2030d86b6ab9168132b88":[8,0,0,0,2,4,123],
+"d2/d83/dhcp4__lexer_8cc.html#a56858d18c7eda4f53664496ef566f651":[8,0,0,0,2,4,90],
+"d2/d83/dhcp4__lexer_8cc.html#a57988ccbac3b3a3038cfaa354e9a673a":[8,0,0,0,2,4,115],
+"d2/d83/dhcp4__lexer_8cc.html#a59b013e3366c41f95b4cb836d83757ea":[8,0,0,0,2,4,41],
+"d2/d83/dhcp4__lexer_8cc.html#a5bc6f1a5f7812508f425b08283f13ae8":[8,0,0,0,2,4,160],
+"d2/d83/dhcp4__lexer_8cc.html#a5be541efdb129f7cefb2437f52fe7359":[8,0,0,0,2,4,145],
+"d2/d83/dhcp4__lexer_8cc.html#a5c2bc4886ba4e083f676a6a8a9b42d0f":[8,0,0,0,2,4,117],
+"d2/d83/dhcp4__lexer_8cc.html#a5e36364965360da7b7cdfc2188e0af84":[8,0,0,0,2,4,184],
+"d2/d83/dhcp4__lexer_8cc.html#a609d19f40900ecc2a5f812d9388c21fb":[8,0,0,0,2,4,58],
+"d2/d83/dhcp4__lexer_8cc.html#a6198b2fcf96178b24ad4efff2a3debb0":[8,0,0,0,2,4,107],
+"d2/d83/dhcp4__lexer_8cc.html#a61b01b6b236b05090b972f8fd95da539":[8,0,0,0,2,4,179],
+"d2/d83/dhcp4__lexer_8cc.html#a64d16067d4399dd64d107354e847e05e":[8,0,0,0,2,4,110],
+"d2/d83/dhcp4__lexer_8cc.html#a6849452203fd033f103556fdf858fd33":[8,0,0,0,2,4,93],
+"d2/d83/dhcp4__lexer_8cc.html#a68792d73820bc46a71d3d4e613f0b977":[8,0,0,0,2,4,83],
+"d2/d83/dhcp4__lexer_8cc.html#a688eb21a22db27c2b2bd5836943cdcbe":[8,0,0,0,2,4,19],
+"d2/d83/dhcp4__lexer_8cc.html#a690504b662e4281515bf12722df178ba":[8,0,0,0,2,4,91],
+"d2/d83/dhcp4__lexer_8cc.html#a6c5cf8c3b7a69bf60a87dd6eb00fe579":[8,0,0,0,2,4,95],
+"d2/d83/dhcp4__lexer_8cc.html#a6f64479b1e944a52e55bc5210feb91db":[8,0,0,0,2,4,38],
+"d2/d83/dhcp4__lexer_8cc.html#a70f82d43d4797bb2a50f7678ddbfbda5":[8,0,0,0,2,4,168],
+"d2/d83/dhcp4__lexer_8cc.html#a71ca89b3656acd0552f14949a571560b":[8,0,0,0,2,4,53],
+"d2/d83/dhcp4__lexer_8cc.html#a7411c3bab9eca1afee90113c2d22da37":[8,0,0,0,2,4,181],
+"d2/d83/dhcp4__lexer_8cc.html#a745d37b5e002b2e5f93ad42ea7b554be":[8,0,0,0,2,4,128],
+"d2/d83/dhcp4__lexer_8cc.html#a74c8ccc0c162aaa83dc823d4dff4f62d":[8,0,0,0,2,4,5],
+"d2/d83/dhcp4__lexer_8cc.html#a7682c8d9cec0859408d2421fbe4a5570":[8,0,0,0,2,4,63],
+"d2/d83/dhcp4__lexer_8cc.html#a790a191a93ef4d3b8c0bb43fd7480052":[8,0,0,0,2,4,144],
+"d2/d83/dhcp4__lexer_8cc.html#a7b0840dff4a2ef1702118aa12264b2a7":[8,0,0,0,2,4,149],
+"d2/d83/dhcp4__lexer_8cc.html#a7da304d8ef6c688c0835d35296fe61c2":[8,0,0,0,2,4,167],
+"d2/d83/dhcp4__lexer_8cc.html#a7f71d7fa2c403eb4b2f38cb9536f3c63":[8,0,0,0,2,4,9],
+"d2/d83/dhcp4__lexer_8cc.html#a803397ab738ee8630166680646a2d913":[8,0,0,0,2,4,108],
+"d2/d83/dhcp4__lexer_8cc.html#a80d41707f7f990616888fe1d72211a38":[8,0,0,0,2,4,165],
 "d2/d83/dhcp4__lexer_8cc.html#a817a6a24af62508b5a35f4bed5f56a2e":[8,0,0,0,2,4,61],
 "d2/d83/dhcp4__lexer_8cc.html#a828cc83270f8f5bb1688e14dd4e28128":[8,0,0,0,2,4,141],
 "d2/d83/dhcp4__lexer_8cc.html#a835f10dd1ab4bf9a80c4cd80ee6e3058":[8,0,0,0,2,4,47],
@@ -100,15 +133,15 @@ var NAVTREEINDEX27 =
 "d2/d83/dhcp4__lexer_8cc.html#afa07a629486cb790560bb95713ec7794":[8,0,0,0,2,4,120],
 "d2/d83/dhcp4__lexer_8cc.html#afca8968a4317529bdbdc6ed77cd1e479":[8,0,0,0,2,4,137],
 "d2/d83/dhcp4__lexer_8cc_source.html":[8,0,0,0,2,4],
-"d2/d85/server__collection_8cc.html":[8,0,0,2,9,15],
-"d2/d85/server__collection_8cc_source.html":[8,0,0,2,9,15],
-"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html":[6,0,2,11,134],
-"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html":[7,0,1,9,134],
-"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html#a6d9168bbaa3d07391b0af3cbb43fda75":[6,0,2,11,134,0],
-"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html#a6d9168bbaa3d07391b0af3cbb43fda75":[7,0,1,9,134,0],
-"d2/d86/docs.html":[0,52],
-"d2/d86/docs.html#docsDevelGuide":[0,52,1],
-"d2/d86/docs.html#docsNewCommand":[0,52,0],
+"d2/d85/server__collection_8cc.html":[8,0,0,2,8,15],
+"d2/d85/server__collection_8cc_source.html":[8,0,0,2,8,15],
+"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html":[6,0,2,11,129],
+"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html":[7,0,1,9,129],
+"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html#a6d9168bbaa3d07391b0af3cbb43fda75":[6,0,2,11,129,0],
+"d2/d86/classisc_1_1dhcp_1_1InvalidSocketType.html#a6d9168bbaa3d07391b0af3cbb43fda75":[7,0,1,9,129,0],
+"d2/d86/docs.html":[0,51],
+"d2/d86/docs.html#docsDevelGuide":[0,51,1],
+"d2/d86/docs.html#docsNewCommand":[0,51,0],
 "d2/d87/lfc__messages_8cc.html":[8,0,0,0,4,4],
 "d2/d87/lfc__messages_8cc.html#a0e579d830596f831f1a3ac73984f83f3":[8,0,0,0,4,4,2],
 "d2/d87/lfc__messages_8cc.html#a57b1d65f25b3b1e6cf8e43b275ccc574":[8,0,0,0,4,4,8],
@@ -122,81 +155,82 @@ var NAVTREEINDEX27 =
 "d2/d87/lfc__messages_8cc.html#ad89fe4ef7753dfc41f16ba3944288993":[8,0,0,0,4,4,6],
 "d2/d87/lfc__messages_8cc.html#aeb1f990516fc8e0e5fda319181509f37":[8,0,0,0,4,4,5],
 "d2/d87/lfc__messages_8cc_source.html":[8,0,0,0,4,4],
-"d2/d89/response__parser_8cc.html":[8,0,0,2,17,53],
-"d2/d89/response__parser_8cc_source.html":[8,0,0,2,17,53],
-"d2/d8c/classify_8h.html":[8,0,0,2,10,1],
-"d2/d8c/classify_8h.html#a09b47054f2acf750a8be020d40c9fc8b":[8,0,0,2,10,1,1],
-"d2/d8c/classify_8h_source.html":[8,0,0,2,10,1],
+"d2/d89/response__parser_8cc.html":[8,0,0,2,16,53],
+"d2/d89/response__parser_8cc_source.html":[8,0,0,2,16,53],
+"d2/d8c/classify_8h.html":[8,0,0,2,9,1],
+"d2/d8c/classify_8h.html#a08a03a67f88a58d90ee9e77c7a406cc6":[8,0,0,2,9,1,4],
+"d2/d8c/classify_8h.html#a09b47054f2acf750a8be020d40c9fc8b":[8,0,0,2,9,1,3],
+"d2/d8c/classify_8h_source.html":[8,0,0,2,9,1],
 "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html":[6,0,2,17,12],
 "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html":[7,0,1,15,12],
 "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html#ae2175e7f64e9e559020a9c34584225f7":[6,0,2,17,12,0],
 "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html#ae2175e7f64e9e559020a9c34584225f7":[7,0,1,15,12,0],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html":[6,0,2,11,266],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html":[7,0,1,9,266],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#a384c70fed2a41a5d6f983d0b5bde61fd":[6,0,2,11,266,1],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#a384c70fed2a41a5d6f983d0b5bde61fd":[7,0,1,9,266,1],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#ad7d5805cbe5153ba87e29dcd60237ad7":[6,0,2,11,266,0],
-"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#ad7d5805cbe5153ba87e29dcd60237ad7":[7,0,1,9,266,0],
-"d2/d8e/log__formatter_8h.html":[8,0,0,2,18,7],
-"d2/d8e/log__formatter_8h.html#acdc106b2cc6ac615db061e6fd0b618dc":[8,0,0,2,18,7,3],
-"d2/d8e/log__formatter_8h.html#ad50f68d13bce8781d12aa5cf54510647":[8,0,0,2,18,7,4],
-"d2/d8e/log__formatter_8h_source.html":[8,0,0,2,18,7],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html":[7,0,1,12,2,7],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html":[6,0,2,11,262],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html":[7,0,1,9,262],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#a384c70fed2a41a5d6f983d0b5bde61fd":[6,0,2,11,262,1],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#a384c70fed2a41a5d6f983d0b5bde61fd":[7,0,1,9,262,1],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#ad7d5805cbe5153ba87e29dcd60237ad7":[6,0,2,11,262,0],
+"d2/d8e/classisc_1_1dhcp_1_1Pools6ListParser.html#ad7d5805cbe5153ba87e29dcd60237ad7":[7,0,1,9,262,0],
+"d2/d8e/log__formatter_8h.html":[8,0,0,2,17,7],
+"d2/d8e/log__formatter_8h.html#acdc106b2cc6ac615db061e6fd0b618dc":[8,0,0,2,17,7,3],
+"d2/d8e/log__formatter_8h.html#ad50f68d13bce8781d12aa5cf54510647":[8,0,0,2,17,7,4],
+"d2/d8e/log__formatter_8h_source.html":[8,0,0,2,17,7],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html":[6,0,2,14,2,7],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a29992874ff4a35cead2349eec2306302":[6,0,2,14,2,7,11],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html":[7,0,1,12,2,7],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a29992874ff4a35cead2349eec2306302":[7,0,1,12,2,7,11],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a29992874ff4a35cead2349eec2306302":[6,0,2,14,2,7,11],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a363e3b79e94294c6ab668045aff38858":[6,0,2,14,2,7,5],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a363e3b79e94294c6ab668045aff38858":[7,0,1,12,2,7,5],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a41631e33d6f8884d17bbaa467fe3cc84":[7,0,1,12,2,7,12],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a41631e33d6f8884d17bbaa467fe3cc84":[6,0,2,14,2,7,12],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a5dd3b053499c7b05977eec90e974eb56":[6,0,2,14,2,7,7],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a5dd3b053499c7b05977eec90e974eb56":[7,0,1,12,2,7,7],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a6122bec836325a68417f251bf57a563e":[7,0,1,12,2,7,2],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a6122bec836325a68417f251bf57a563e":[6,0,2,14,2,7,2],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a6122bec836325a68417f251bf57a563e":[7,0,1,12,2,7,2],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a6b862fdacc38130d85580abd212c470e":[7,0,1,12,2,7,14],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a6b862fdacc38130d85580abd212c470e":[6,0,2,14,2,7,14],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a78ecd4553f2228294047d1fd63cbd6c9":[7,0,1,12,2,7,4],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a78ecd4553f2228294047d1fd63cbd6c9":[6,0,2,14,2,7,4],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a892a3759082e2615a63bceb1f019404b":[7,0,1,12,2,7,6],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a78ecd4553f2228294047d1fd63cbd6c9":[7,0,1,12,2,7,4],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a892a3759082e2615a63bceb1f019404b":[6,0,2,14,2,7,6],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9874c2b4a335b66b76857bc6afc1a62c":[7,0,1,12,2,7,8],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a892a3759082e2615a63bceb1f019404b":[7,0,1,12,2,7,6],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9874c2b4a335b66b76857bc6afc1a62c":[6,0,2,14,2,7,8],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9eeaea785c59105d01315813fe9f6fca":[6,0,2,14,2,7,3],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9874c2b4a335b66b76857bc6afc1a62c":[7,0,1,12,2,7,8],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9eeaea785c59105d01315813fe9f6fca":[7,0,1,12,2,7,3],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#a9eeaea785c59105d01315813fe9f6fca":[6,0,2,14,2,7,3],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ad4de41bf3b2aa07214fc255280f27a9c":[6,0,2,14,2,7,9],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ad4de41bf3b2aa07214fc255280f27a9c":[7,0,1,12,2,7,9],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ad909dbbe330d501697d66fa737d0cb6d":[6,0,2,14,2,7,13],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ad909dbbe330d501697d66fa737d0cb6d":[7,0,1,12,2,7,13],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#adc424b089a66b6cefae563d373e449c7":[6,0,2,14,2,7,10],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#adc424b089a66b6cefae563d373e449c7":[7,0,1,12,2,7,10],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#add5a3c30f70b05be2b4228d7c217577d":[6,0,2,14,2,7,15],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#add5a3c30f70b05be2b4228d7c217577d":[7,0,1,12,2,7,15],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#add5a3c30f70b05be2b4228d7c217577d":[6,0,2,14,2,7,15],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ade9e1d7cfb9711f17d9eddcf38bad9d1":[7,0,1,12,2,7,1],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#ade9e1d7cfb9711f17d9eddcf38bad9d1":[6,0,2,14,2,7,1],
-"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#affc899f89d39c52ada742f5404867ac0":[6,0,2,14,2,7,0],
 "d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#affc899f89d39c52ada742f5404867ac0":[7,0,1,12,2,7,0],
-"d2/d90/cfg__host__operations_8h.html":[8,0,0,2,12,27],
-"d2/d90/cfg__host__operations_8h.html#a0c3c0554705cbbcd741d00e9e5ce5ef6":[8,0,0,2,12,27,1],
-"d2/d90/cfg__host__operations_8h.html#a540ee92af17cf11637c0d911fd1f7c4a":[8,0,0,2,12,27,2],
-"d2/d90/cfg__host__operations_8h_source.html":[8,0,0,2,12,27],
-"d2/d90/classisc_1_1cryptolink_1_1RNG.html":[6,0,2,6,12],
+"d2/d8f/classisc_1_1eval_1_1EvalParser_1_1value__type.html#affc899f89d39c52ada742f5404867ac0":[6,0,2,14,2,7,0],
+"d2/d90/cfg__host__operations_8h.html":[8,0,0,2,11,28],
+"d2/d90/cfg__host__operations_8h.html#a0c3c0554705cbbcd741d00e9e5ce5ef6":[8,0,0,2,11,28,1],
+"d2/d90/cfg__host__operations_8h.html#a540ee92af17cf11637c0d911fd1f7c4a":[8,0,0,2,11,28,2],
+"d2/d90/cfg__host__operations_8h_source.html":[8,0,0,2,11,28],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html":[7,0,1,5,11],
-"d2/d90/classisc_1_1cryptolink_1_1RNG.html#a27f8ad78c37617ba086dabaf961e84cd":[7,0,1,5,11,3],
+"d2/d90/classisc_1_1cryptolink_1_1RNG.html":[6,0,2,6,12],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#a27f8ad78c37617ba086dabaf961e84cd":[6,0,2,6,12,3],
-"d2/d90/classisc_1_1cryptolink_1_1RNG.html#a917a50d587a0152af87788e477baa1ed":[7,0,1,5,11,0],
+"d2/d90/classisc_1_1cryptolink_1_1RNG.html#a27f8ad78c37617ba086dabaf961e84cd":[7,0,1,5,11,3],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#a917a50d587a0152af87788e477baa1ed":[6,0,2,6,12,0],
+"d2/d90/classisc_1_1cryptolink_1_1RNG.html#a917a50d587a0152af87788e477baa1ed":[7,0,1,5,11,0],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#a93b6e7a725164ecc7cef9488c7c75180":[7,0,1,5,11,1],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#a93b6e7a725164ecc7cef9488c7c75180":[6,0,2,6,12,1],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#acfc21beb176fc829d34e41fa66352863":[6,0,2,6,12,2],
 "d2/d90/classisc_1_1cryptolink_1_1RNG.html#acfc21beb176fc829d34e41fa66352863":[7,0,1,5,11,2],
 "d2/d93/classisc_1_1dns_1_1IncompleteRRType.html":[6,0,2,13,21],
 "d2/d93/classisc_1_1dns_1_1IncompleteRRType.html":[7,0,1,11,20],
-"d2/d93/classisc_1_1dns_1_1IncompleteRRType.html#ae9fbb063e2114f43e99b935f0b871dd6":[6,0,2,13,21,0],
 "d2/d93/classisc_1_1dns_1_1IncompleteRRType.html#ae9fbb063e2114f43e99b935f0b871dd6":[7,0,1,11,20,0],
-"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html":[7,0,1,9,14],
-"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html":[6,0,2,11,14],
-"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html#a027ea73590e169216df16409e84b6a91":[7,0,1,9,14,0],
-"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html#a027ea73590e169216df16409e84b6a91":[6,0,2,11,14,0],
+"d2/d93/classisc_1_1dns_1_1IncompleteRRType.html#ae9fbb063e2114f43e99b935f0b871dd6":[6,0,2,13,21,0],
+"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html":[7,0,1,9,13],
+"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html":[6,0,2,11,13],
+"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html#a027ea73590e169216df16409e84b6a91":[6,0,2,11,13,0],
+"d2/d96/classisc_1_1dhcp_1_1CBControlDHCPv6.html#a027ea73590e169216df16409e84b6a91":[7,0,1,9,13,0],
 "d2/d96/ctrlSocket.html":[0,29],
 "d2/d96/ctrlSocket.html#ctrlSocketClient":[0,29,1],
 "d2/d96/ctrlSocket.html#ctrlSocketConnections":[0,29,3],
@@ -205,49 +239,15 @@ var NAVTREEINDEX27 =
 "d2/d96/ctrlSocket.html#ctrlSocketOverview":[0,29,0],
 "d2/d98/io__service__signal_8cc.html":[8,0,0,2,1,24],
 "d2/d98/io__service__signal_8cc_source.html":[8,0,0,2,1,24],
-"d2/d99/protocol__util_8cc.html":[8,0,0,2,10,89],
-"d2/d99/protocol__util_8cc.html#a62e697f43e7c7d2066110a12926b1bec":[8,0,0,2,10,89,1],
-"d2/d99/protocol__util_8cc.html#a63450931bb671c97ca4af59badcfde29":[8,0,0,2,10,89,3],
-"d2/d99/protocol__util_8cc.html#a6b8d7d33636ddf8805a91e77fe3f88ca":[8,0,0,2,10,89,2],
-"d2/d99/protocol__util_8cc.html#ab362c015f6f5a887894a6678adcc8b5f":[8,0,0,2,10,89,0],
-"d2/d99/protocol__util_8cc.html#ada3b6844c83a8fc9d0f11112f87c025e":[8,0,0,2,10,89,4],
-"d2/d99/protocol__util_8cc_source.html":[8,0,0,2,10,89],
+"d2/d99/protocol__util_8cc.html":[8,0,0,2,9,90],
+"d2/d99/protocol__util_8cc.html#a62e697f43e7c7d2066110a12926b1bec":[8,0,0,2,9,90,1],
+"d2/d99/protocol__util_8cc.html#a63450931bb671c97ca4af59badcfde29":[8,0,0,2,9,90,3],
+"d2/d99/protocol__util_8cc.html#a6b8d7d33636ddf8805a91e77fe3f88ca":[8,0,0,2,9,90,2],
+"d2/d99/protocol__util_8cc.html#ab362c015f6f5a887894a6678adcc8b5f":[8,0,0,2,9,90,0],
+"d2/d99/protocol__util_8cc.html#ada3b6844c83a8fc9d0f11112f87c025e":[8,0,0,2,9,90,4],
+"d2/d99/protocol__util_8cc_source.html":[8,0,0,2,9,90],
 "d2/d9a/cmd__http__listener_8h.html":[8,0,0,2,4,5],
 "d2/d9a/cmd__http__listener_8h.html#afa9c026f0569193fa309f4553065de24":[8,0,0,2,4,5,1],
 "d2/d9a/cmd__http__listener_8h_source.html":[8,0,0,2,4,5],
-"d2/d9a/libdhcp_ddns.html":[0,39],
-"d2/d9a/libdhcp_ddns.html#libdhcp_ddnsIntro":[0,39,0],
-"d2/d9a/libdhcp_ddns.html#libdhcp_ddnsMTConsiderations":[0,39,1],
-"d2/da0/dhcp__queue__control__parser_8h.html":[8,0,0,2,12,1,7],
-"d2/da0/dhcp__queue__control__parser_8h_source.html":[8,0,0,2,12,1,7],
-"d2/da6/stopwatch__impl_8cc.html":[8,0,0,2,24,33],
-"d2/da6/stopwatch__impl_8cc_source.html":[8,0,0,2,24,33],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html":[7,0,1,4,14],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html":[6,0,2,5,14],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a3f31e5aa9cb1d6eb06edbda62830d49e":[6,0,2,5,14,7],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a3f31e5aa9cb1d6eb06edbda62830d49e":[7,0,1,4,14,7],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a57f556be727aba08cda78a51ebd410fa":[7,0,1,4,14,1],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a57f556be727aba08cda78a51ebd410fa":[6,0,2,5,14,1],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a5fc45d3217f41423f283049cc7d40462":[7,0,1,4,14,5],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a5fc45d3217f41423f283049cc7d40462":[6,0,2,5,14,5],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a886ad717dd13c5383700fdc7f3b50f3c":[6,0,2,5,14,6],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a886ad717dd13c5383700fdc7f3b50f3c":[7,0,1,4,14,6],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a99a10621853df8f2d35888c6f3c0f1ee":[6,0,2,5,14,2],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#a99a10621853df8f2d35888c6f3c0f1ee":[7,0,1,4,14,2],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#aae4087b98884ffcdfc8b3fd8d970a250":[6,0,2,5,14,4],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#aae4087b98884ffcdfc8b3fd8d970a250":[7,0,1,4,14,4],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#abbb8fda35841934c46c073fa0fae7a5a":[6,0,2,5,14,8],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#abbb8fda35841934c46c073fa0fae7a5a":[7,0,1,4,14,8],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#abdc78056f1713819df2f247779d5d942":[6,0,2,5,14,3],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#abdc78056f1713819df2f247779d5d942":[7,0,1,4,14,3],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#ad17ffdd0b602ec049cf0ac2201f2dc1d":[6,0,2,5,14,0],
-"d2/da8/classisc_1_1config_1_1JSONFeed.html#ad17ffdd0b602ec049cf0ac2201f2dc1d":[7,0,1,4,14,0],
-"d2/da8/dhcp6_2parser__context__decl_8h.html":[8,0,0,0,3,20],
-"d2/da8/dhcp6_2parser__context__decl_8h_source.html":[8,0,0,0,3,20],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html":[7,0,1,12,0],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html":[6,0,2,14,0],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html#a10895ba619c61eec25151b857d8c69d0":[6,0,2,14,0,0],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html#a10895ba619c61eec25151b857d8c69d0":[7,0,1,12,0,0],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html#a27933f38a75a9feb3280c5a683924f93":[7,0,1,12,0,9],
-"d2/da9/classisc_1_1eval_1_1EvalContext.html#a27933f38a75a9feb3280c5a683924f93":[6,0,2,14,0,9]
+"d2/d9a/libdhcp_ddns.html":[0,38]
 };
